<?php

namespace Teknisa\PAR\Controller;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Teknisa\Libs\Util\Environment;
use Teknisa\PAR\Service\FileServerService;
use Zeedhi\Framework\DataSource\DataSet;

class FileServerController {
    protected $documentosService;
    protected $fileServerBaseUrl;
    protected $environment;
    
    public function __construct(FileServerService $documentosService, $fileServerBaseUrl, Environment $environment) {
        $this->documentosService = $documentosService;
        $this->fileServerBaseUrl = $fileServerBaseUrl;
        $this->environment       = $environment;
        
    }
    /**
     * Baixa um arquivo salvo na pasta temporária
    **/
    public function downloadArquivo(Request $request, Response $response) {
        try {
            $documento = $request->getRow();
            $fileType = $documento["FILETYPE"]; 
            $fileName = base64_decode($documento["FILENAME"]); 
            $fileDir  = sys_get_temp_dir() . DIRECTORY_SEPARATOR . $fileName; 
            
            if(!is_file($fileDir)) {
                throw new \Exception("Operação bloqueada!<br>Arquivo não encontrato.");
            } else {
                $fileSize = filesize($fileDir); 
                FileServerService::downloadArquivo($fileDir, $fileName, $fileType, $fileSize);
            }
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        } 
    }
    
    /**
     * Burca um arquivo no fileServer e salva numa pasta temporária
    **/
    public function getUrlAnexos(Request\Row $request, Response $response) {
        try {
            $microtime = microtime(true);
            $microtime = str_replace(".", "_", $microtime);
            
            $arquivo  = $request->getRow();
            $fileDir  = $this->fileServerBaseUrl . $arquivo["DSCAMINHOARQ"];
            $fileName = $microtime . "_" . str_replace(",", "_", $arquivo["NMARQUIVO"]);
            
            $nrorg       = $this->environment->getNrOrg();
            $fileDirTemp = $this->documentosService->downloadDocFileServer($fileDir, $fileName, $nrorg);
            $fileName    = base64_encode($fileName);
            $fileName    = str_replace(array(",", "&"), "_", $fileName);
            $result      = "/downloadArquivo?requestType=Row&row[FILENAME]=" . urlencode($fileName) . "&row[FILETYPE]=" . $arquivo["DSTIPO"];
            $response->addDataSet(new DataSet("URLDOCUMENTO", array($result)));
        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        } 
    }
}

?>
